pub struct LinkTable {
pub fingerprints: Vec<BlockFingerprint>,
pub links: Vec<StructuralLink>,
}Expand description
Link table — mmap-friendly storage of structural links.
Fields
fingerprints: Vec<BlockFingerprint>links: Vec<StructuralLink>Implementations
Sourceimpl LinkTable
impl LinkTable
Sourcepub fn links_for(&self, block_idx: u32) -> Vec<&StructuralLink>
pub fn links_for(&self, block_idx: u32) -> Vec<&StructuralLink>
Get structural links for a specific block.
Sourcepub fn linked_blocks(&self, block_idx: u32) -> Vec<(u32, f32)>
pub fn linked_blocks(&self, block_idx: u32) -> Vec<(u32, f32)>
Get the other end of a link from a given block.
Sourcepub fn find_similar(&self, text: &str, k: usize) -> Vec<(u32, f32)>
pub fn find_similar(&self, text: &str, k: usize) -> Vec<(u32, f32)>
Find the most structurally similar blocks to a query text.
Sourcepub fn stats(&self) -> FingerprintStats
pub fn stats(&self) -> FingerprintStats
Statistics.