pub struct ReceivedPulse {
pub pulse: Pulse,
pub local_matches: u32,
pub integrated: bool,
}Expand description
Received pulse — a pulse from another instance, integrated into local state.
Fields
pulse: Pulselocal_matches: u32How many local blocks were influenced by this pulse.
integrated: boolWas this pulse already integrated?