pub fn export_binary_snapshot(
reader: &MicroscopeReader,
hebb: &HebbianState,
mirror: &MirrorState,
thought_graph: &ThoughtGraphState,
) -> Vec<u8> ⓘExpand description
Export the full state as a raw binary buffer (VIZ1).
pub fn export_binary_snapshot(
reader: &MicroscopeReader,
hebb: &HebbianState,
mirror: &MirrorState,
thought_graph: &ThoughtGraphState,
) -> Vec<u8> ⓘExport the full state as a raw binary buffer (VIZ1).